@@ -2,22 +2,17 @@
 import re
 import inspect
 
+
 from django import forms
 from django.forms.models import inlineformset_factory, BaseInlineFormSet
-from django.conf import settings
-from django.contrib.auth.models import User
-from django.contrib.contenttypes.models import ContentType
-from django.core.exceptions import ObjectDoesNotExist
 from django.utils.translation import ugettext as _
+from django.utils.timezone import now as tznow
 
-try:
-    from django.utils.timezone import now as tznow
-except ImportError:
-    import datetime
+from pybb import util
+User = util.get_user_model()
+username_field = util.get_username_field()
 
-    tznow = datetime.datetime.now
-
-from pybb.models import Topic, Post, Profile, Attachment, PollAnswer
+from pybb.models import Topic, Post, Attachment, PollAnswer
 from pybb import defaults
 
 
@@ -54,7 +49,7 @@ class BasePollAnswerFormset(BaseInlineFormSet):
 
 
 PollAnswerFormSet = inlineformset_factory(Topic, PollAnswer, extra=2, max_num=defaults.PYBB_POLL_MAX_ANSWERS,
-    form=PollAnswerForm, formset=BasePollAnswerFormset)
+                                          form=PollAnswerForm, formset=BasePollAnswerFormset)
 
 
 class PostForm(forms.ModelForm):
@@ -147,8 +142,7 @@ class PostForm(forms.ModelForm):
                 topic.save()
         else:
             topic = self.topic
-        post = Post(topic=topic, user=self.user, user_ip=self.ip,
-            body=self.cleaned_data['body'])
+        post = Post(topic=topic, user=self.user, user_ip=self.ip, body=self.cleaned_data['body'])
         if not allow_post:
             post.on_moderation = True
         if commit:
@@ -167,26 +161,25 @@ class AdminPostForm(PostForm):
         if args:
             kwargs.update(dict(zip(inspect.getargspec(forms.ModelForm.__init__)[0][1:], args)))
         if 'instance' in kwargs and kwargs['instance']:
-            kwargs.setdefault('initial', {}).update({'login': kwargs['instance'].user.username})
+            kwargs.setdefault('initial', {}).update({'login': getattr(kwargs['instance'].user, username_field)})
         super(AdminPostForm, self).__init__(**kwargs)
 
     def save(self, *args, **kwargs):
         try:
-            self.user = User.objects.filter(username=self.cleaned_data['login']).get()
+            self.user = User.objects.filter(**{username_field: self.cleaned_data['login']}).get()
         except User.DoesNotExist:
-            self.user = User.objects.create_user(self.cleaned_data['login'],
-                '%s@example.com' % self.cleaned_data['login'])
+            if username_field != 'email':
+                create_data = {username_field: self.cleaned_data['login'],
+                               'email': '%s@example.com' % self.cleaned_data['login']}
+            else:
+                create_data = {'email': '%s@example.com' % self.cleaned_data['login']}
+            self.user = User.objects.create(**create_data)
         return super(AdminPostForm, self).save(*args, **kwargs)
 
-try:
-    profile_app, profile_model = settings.AUTH_PROFILE_MODULE.split('.')
-    profile_model = ContentType.objects.get_by_natural_key(profile_app, profile_model).model_class()
-except (AttributeError, ValueError, ObjectDoesNotExist):
-    profile_model = Profile
 
 class EditProfileForm(forms.ModelForm):
     class Meta(object):
-        model = profile_model
+        model = util.get_pybb_profile_model()
         fields = ['signature', 'time_zone', 'language',
                   'show_signatures', 'avatar']
 
@@ -212,13 +205,13 @@ class UserSearchForm(forms.Form):
     def filter(self, qs):
         if self.is_valid():
             query = self.cleaned_data['query']
-            return qs.filter(username__contains=query)
+            return qs.filter(**{'%s__contains' % username_field: query})
         else:
             return qs
 
 
 class PollForm(forms.Form):
-    def __init__(self, topic,  *args, **kwargs):
+    def __init__(self, topic, *args, **kwargs):
         self.topic = topic
 
         super(PollForm, self).__init__(*args, **kwargs)
