@@ -2,6 +2,7 @@
 
 from django.utils import translation
 from django.db.models import ObjectDoesNotExist
+from pybb import util
 
 from pybb.signals import user_saved
 
@@ -13,12 +14,12 @@ class PybbMiddleware(object):
                 # Here we try to load profile, but can get error
                 # if user created during syncdb but profile model
                 # under south control. (Like pybb.Profile).
-                profile = request.user.get_profile()
+                profile = util.get_pybb_profile(request.user)
             except ObjectDoesNotExist:
                 # Ok, we should create new profile for this user
                 # and grant permissions for add posts
                 user_saved(request.user, created=True)
-                profile = request.user.get_profile()
+                profile = util.get_pybb_profile(request.user)
 
             language = translation.get_language_from_request(request)
 
