@@ -4,28 +4,28 @@ import os.path
 import uuid
 
 from django.db import models, transaction
-from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.db.utils import IntegrityError
 from django.utils.html import strip_tags
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
+from django.utils.timezone import now as tznow
 
 from annoying.fields import AutoOneToOneField
-from sorl.thumbnail import ImageField
-from pybb.util import unescape
+try:
+    from sorl.thumbnail import ImageField
+except ImportError:
+    from django.db.models import ImageField
+from pybb.util import unescape, get_user_model, get_username_field
+
+User = get_user_model()
+username_field = get_username_field()
 
 try:
     from hashlib import sha1
 except ImportError:
     from sha import sha as sha1
 
-try:
-    from django.utils.timezone import now as tznow
-except ImportError:
-    import datetime
-    tznow = datetime.datetime.now
-
 try:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules([], ["^annoying\.fields\.JSONField"])
@@ -47,6 +47,7 @@ TZ_CHOICES = [(float(x[0]), x[1]) for x in (
 (11.5, '+11.5'), (12, '+12'), (13, '+13'), (14, '+14'),
 )]
 
+
 #noinspection PyUnusedLocal
 def get_file_path(instance, filename, to='pybb/avatar'):
     """
@@ -59,6 +60,7 @@ def get_file_path(instance, filename, to='pybb/avatar'):
     filename = "%s.%s" % (uuid.uuid4(), ext)
     return os.path.join(to, filename)
 
+
 class Category(models.Model):
     name = models.CharField(_('Name'), max_length=80)
     position = models.IntegerField(_('Position'), blank=True, default=0)
@@ -111,7 +113,7 @@ class Forum(models.Model):
         return self.name
 
     def update_counters(self):
-        posts = Post.objects.filter(topic__forum__id=self.id)
+        posts = Post.objects.filter(topic__forum_id=self.id)
         self.post_count = posts.count()
         self.topic_count = Topic.objects.filter(forum=self).count()
         try:
@@ -225,7 +227,7 @@ class Topic(models.Model):
 
     def update_counters(self):
         self.post_count = self.posts.count()
-        last_post = Post.objects.filter(topic__id=self.id).order_by('-created')[0]
+        last_post = Post.objects.filter(topic_id=self.id).order_by('-created')[0]
         self.updated = last_post.updated or last_post.created
         self.save()
 
@@ -384,7 +386,7 @@ class Profile(PybbProfile):
         verbose_name_plural = _('Profiles')
 
     def get_absolute_url(self):
-        return reverse('pybb:user', kwargs={'username': self.user.username})
+        return reverse('pybb:user', kwargs={'username': getattr(self.user, username_field)})
 
 
 class Attachment(models.Model):
