@@ -7,7 +7,7 @@ from django.utils import translation
 from django.contrib.sites.models import Site
 from django import forms
 
-from pybb import defaults
+from pybb import defaults, util
 
 if defaults.PYBB_USE_DJANGO_MAILER:
     try:
@@ -31,7 +31,7 @@ def notify_topic_subscribers(post):
                     #invalid email
                     continue
                 old_lang = translation.get_language()
-                lang = user.get_profile().language or settings.LANGUAGE_CODE
+                lang = util.get_pybb_profile(user).language or settings.LANGUAGE_CODE
                 translation.activate(lang)
                 delete_url = reverse('pybb:delete_subscription', args=[post.topic.id])
                 current_site = Site.objects.get_current()
