@@ -3,7 +3,8 @@
 import time, datetime
 import os
 
-from django.contrib.auth.models import User, Permission
+from django.contrib.auth.models import Permission
+from django.conf import settings
 from django.core import mail
 from django.core.urlresolvers import reverse
 from django.core.exceptions import ValidationError
@@ -11,13 +12,17 @@ from django.test import TestCase
 from django.test.client import Client
 from pybb.templatetags.pybb_tags import pybb_is_topic_unread, pybb_topic_unread, pybb_forum_unread
 
+from pybb import util
+User = util.get_user_model()
+username_field = util.get_username_field()
+
 try:
     from lxml import html
 except ImportError:
     raise Exception('PyBB requires lxml for self testing')
 
 from pybb import defaults
-from pybb.models import *
+from pybb.models import Topic, TopicReadTracker, Forum, ForumReadTracker, Post, Category, PollAnswer, Profile
 
 __author__ = 'zeus'
 
@@ -90,7 +95,7 @@ class FeaturesTest(TestCase, SharedTestModule):
 
     def test_profile_language_default(self):
         user = User.objects.create_user(username='user2', password='user2', email='user2@example.com')
-        self.assertEqual(user.get_profile().language, settings.LANGUAGE_CODE)
+        self.assertEqual(util.get_pybb_profile(user).language, settings.LANGUAGE_CODE)
 
     def test_profile_edit(self):
         # Self profile edit
@@ -475,6 +480,41 @@ class FeaturesTest(TestCase, SharedTestModule):
             [t.unread for t in pybb_forum_unread([forum_1, forum_2], user_ann)],
             [True, False])
 
+    def test_open_first_unread_post(self):
+        forum_1 = self.forum
+        topic_1 = Topic.objects.create(name='topic_1', forum=forum_1, user=self.user)
+        topic_2 = Topic.objects.create(name='topic_2', forum=forum_1, user=self.user)
+
+        post_1_1 = Post.objects.create(topic=topic_1, user=self.user, body='1_1')
+        post_1_2 = Post.objects.create(topic=topic_1, user=self.user, body='1_2')
+        post_2_1 = Post.objects.create(topic=topic_2, user=self.user, body='2_1')
+
+        user_ann = User.objects.create_user('ann', 'ann@localhost', 'ann')
+        client_ann = Client()
+        client_ann.login(username='ann', password='ann')
+
+        response = client_ann.get(reverse('pybb:topic', kwargs={'pk': topic_1.id }), data={'first-unread': 1},
+                                  follow=True)
+        self.assertRedirects(response,
+                             '%s?page=%d#post-%d' % (reverse('pybb:topic', kwargs={'pk': topic_1.id}), 1, post_1_1.id))
+        response = client_ann.get(reverse('pybb:topic', kwargs={'pk': topic_1.id }), data={'first-unread': 1},
+                                  follow=True)
+        self.assertRedirects(response,
+                             '%s?page=%d#post-%d' % (reverse('pybb:topic', kwargs={'pk': topic_1.id}), 1, post_1_2.id))
+
+        response = client_ann.get(reverse('pybb:topic', kwargs={'pk': topic_2.id }), data={'first-unread': 1},
+                                  follow=True)
+        self.assertRedirects(response,
+                             '%s?page=%d#post-%d' % (reverse('pybb:topic', kwargs={'pk': topic_2.id}), 1, post_2_1.id))
+
+        post_1_3 = Post.objects.create(topic=topic_1, user=self.user, body='1_3')
+        post_1_4 = Post.objects.create(topic=topic_1, user=self.user, body='1_4')
+
+        response = client_ann.get(reverse('pybb:topic', kwargs={'pk': topic_1.id }), data={'first-unread': 1},
+                                  follow=True)
+        self.assertRedirects(response,
+                             '%s?page=%d#post-%d' % (reverse('pybb:topic', kwargs={'pk': topic_1.id}), 1, post_1_3.id))
+
     def test_latest_topics(self):
         topic_1 = self.topic
         topic_1.updated = datetime.datetime.utcnow()
@@ -796,12 +836,12 @@ class FeaturesTest(TestCase, SharedTestModule):
         topic.save()
         post = Post(topic=topic, user=self.user, body='test') # another post
         post.save()
-        self.assertEqual(self.user.get_profile().post_count, 2)
+        self.assertEqual(util.get_pybb_profile(self.user).post_count, 2)
         post.body = 'test2'
         post.save()
-        self.assertEqual(Profile.objects.get(pk=self.user.get_profile().pk).post_count, 2)
+        self.assertEqual(Profile.objects.get(pk=util.get_pybb_profile(self.user).pk).post_count, 2)
         post.delete()
-        self.assertEqual(Profile.objects.get(pk=self.user.get_profile().pk).post_count, 1)
+        self.assertEqual(Profile.objects.get(pk=util.get_pybb_profile(self.user).pk).post_count, 1)
 
     def tearDown(self):
         defaults.PYBB_ENABLE_ANONYMOUS_POST = self.ORIG_PYBB_ENABLE_ANONYMOUS_POST
